@@ -1,12 +1,14 @@
 from ngutils.functions import *
 
-__version__ = '0.9.18'
+__version__ = '0.9.21'
 
 __all__ = [
     'accel_steps',
     'flatten',
     'hash_hd',
+    'host_extract',
     'json_to_list',
+    'jupiter_detected',
     'read_files_contents',
     'read_urls_contents',
     'reduce_content',
