@@ -52,7 +52,7 @@ def view_types(data: Union[pd.DataFrame, pd.Series, list, dict], dropna: Optiona
 
     df_output['(unique)'] = [data[c].astype(str).nunique(dropna) for c in data.columns]
     df_output.columns = [columns_exch.get(str(x), x) for x in df_output.columns]
-    if sys.argv[-1].endswith('json'):
+    if jupiter_detected():
         display(df_output.head(60))
     else:
         print(df_output.head(60))
@@ -78,7 +78,7 @@ def read_urls_contents(
     session : requests.Session, optional
         Auth session.
     parser : function, optional
-        Function for content preprocessing in main thread f(decoded_content: str, final_url: str) -> None.
+        Function for content preprocessing in main thread f(decoded_content: str, final_url: str, source_url: str) -> None.
     encoding : str, optional
         Encoding of the content. By default, the content encoding is determined automatically.
     max_retries : int, optional
@@ -146,9 +146,9 @@ def read_urls_contents(
             url = future_load_url[future]
             try:
                 if output_type is None:
-                    parser(*future.result())
+                    parser(*future.result(), url)
                 else:
-                    buf.write(future.result()[0] if parser is None else parser(*future.result()))
+                    buf.write(future.result()[0] if parser is None else parser(*future.result(), url))
             except Exception as exc:
                 if error_page_output is None:
                     raise Exception(f'Download error\n{url}|{exc}')
@@ -215,8 +215,8 @@ clean_rules = Cleaner(
     forms = True,
     annoying_tags = True,
     remove_tags = ['abbr', 'acronym', 'b', 'big', 'blockquote', 'cite', 'code', 'del', 'dfn', 'em', 'i', 'ins', 
-                   'kbd', 's', 'samp', 'small', 'span', 'strike', 'strong', 'sub', 'sup', 'tt', 'u', 'var', ],
-    kill_tags = ['figure', 'footer', 'header', 'img', 'svg', 'template'],
+                   'kbd', 's', 'samp', 'small', 'strike', 'strong', 'sub', 'sup', 'tt', 'u', 'var', ],
+    kill_tags = ['figure', 'footer', 'img', 'svg', 'template'],
     remove_unknown_tags = False,
     safe_attrs_only = True,
     add_nofollow = False,
@@ -367,3 +367,12 @@ def json_to_list(unflat: dict) -> list:
             json_list.append([path[1:], val])
     parse(unflat, '')
     return json_list
+
+
+def jupiter_detected() -> bool:
+    return sys.argv[-1].endswith('json')
+
+def host_extract(url: str) -> str:
+    return url.replace('//www.', '//').replace('https://', '').replace('http://', '').partition('/')[0]
+    # return u.removeprefix('https://').removeprefix('http://').removeprefix('www.').partition('/')[0]
+    #          ^ new in python 3.9
